@@ -18,7 +18,7 @@
  *
  * May, 2000. Implemented on FreeBSD 4.0-RELEASE (Compaq Armada M700)
  *
-$Id: properties.c,v 1.18 2002/02/16 18:18:48 kevinv Exp $
+$Id: properties.c,v 1.19.2.1 2002/07/10 23:15:15 mmclouglin Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -56,6 +56,7 @@ $Id: properties.c,v 1.18 2002/02/16 18:18:48 kevinv Exp $
 #include <gtk/gtkspinbutton.h>
 
 #include <panel-applet.h>
+#include <panel-applet-gconf.h>
 /*#include <status-docklet.h>*/
 
 #include "battstat.h"
@@ -235,18 +236,18 @@ response_cb (GtkDialog *dialog, gint id, gpointer data)
 }
 
 void
-prop_cb (PanelApplet *applet, gpointer data)
+prop_cb (BonoboUIComponent *uic,
+	 ProgressData      *battstat,
+	 const char        *verb)
 {
-  ProgressData   *battstat = data;
-  GladeXML       *glade_xml;
-  GtkWidget      *layout_table;
-  GtkWidget      *preview_hbox;
-  GtkStyle       *teststyle;
-  GtkWidget      *widget;
-  GtkWidget      *batterypixwid, *statuspixwid;
-  guint           percentage;
+  GladeXML  *glade_xml;
+  GtkWidget *layout_table;
+  GtkWidget *preview_hbox;
+  GtkWidget *widget;
+  GtkWidget *batterypixwid, *statuspixwid;
+  guint      percentage;
 
-  apm_readinfo();
+  apm_readinfo (PANEL_APPLET (battstat->applet));
 
 #ifdef __FreeBSD__
   percentage = apminfo.ai_batt_life;
@@ -296,17 +297,15 @@ prop_cb (PanelApplet *applet, gpointer data)
 		      GTK_SIGNAL_FUNC (adj_value_changed_cb), battstat);
 
   preview_hbox = glade_xml_get_widget (glade_xml, "preview_hbox");
-  
-  teststyle = gtk_widget_get_style( GTK_WIDGET (battstat->prop_win) );
 
   battstat->testpixmap = gdk_pixmap_create_from_xpm_d (battstat->applet->window,
 						       &battstat->testmask,
-						       &teststyle->bg[GTK_STATE_NORMAL],
+						       NULL,
 						       battery_gray_xpm); 
 
   battstat->testpixbuffer = gdk_pixmap_create_from_xpm_d (battstat->applet->window,
 							  &battstat->testpixmask,
-							  &teststyle->bg[GTK_STATE_NORMAL],
+							  NULL,
 							  battery_gray_xpm); 
 
   battstat->testpixgc = gdk_gc_new (battstat->testpixmap);
