@@ -37,6 +37,8 @@
 #include <libart_lgpl/art_pixbuf.h>
 #include <libart_lgpl/art_rgb_rgba_affine.h>
 #include <libart_lgpl/art_affine.h>
+
+#include <gconf/gconf-client.h>
  
 #include <sys/types.h>
 #include <dirent.h>		/* for opendir() et al. */
@@ -70,7 +72,7 @@ struct _GkbPropertyBoxInfo
 
   /* Keymaps */
   GList *keymaps;              /* A list of GkbKemap pointers */
-  GtkList *list;               /* The widget displaying the keymaps */
+  GtkTreeView *list;           /* The widget displaying the keymaps */
   GkbKeymap *selected_keymap;  /* A pointer to the selected keymap */
 
   /* Hotkey Entry */
@@ -86,6 +88,7 @@ struct _GkbPropertyBoxInfo
   GkbMode mode;
 };
 
+
 struct _GkbKeymap
 {
   gint i;
@@ -129,6 +132,7 @@ struct _GKB
   GtkWidget *darea_frame;
   GtkWidget *image;
   GtkWidget *addwindow;
+  GtkTooltips *tooltips;
 
   gint n;
   gint cur;
@@ -169,6 +173,9 @@ void gkb_update (GKB *gkb, gboolean set_command);
 void alert (const gchar * str);
 void applet_save_session (void);
 
+void add_atk_relation(GtkWidget *obj1, GtkWidget *obj2, AtkRelationType type);  
+void add_atk_namedesc(GtkWidget *widget, const gchar *name, const gchar *desc); 
+
 /* prop.c */
 void gkb_apply (GkbPropertyBoxInfo * pbi);
 void properties_dialog (BonoboUIComponent *uic,
@@ -212,10 +219,43 @@ gboolean convert_string_to_keysym_state(const char *string,
 					guint *state);
 char * convert_keysym_state_to_string(guint keysym,
 					guint state);
+void gkb_xgrab   (int        keycode,
+		  int        modifiers,
+		  GdkWindow *root_window);
+void gkb_xungrab (int        keycode,
+		  int        modifiers,
+		  GdkWindow *root_window);
+
 void grab_button_pressed (GtkButton *button, gpointer data);
 
-void gkb_xgrab(gint keycode, gint modifiers);
-void gkb_xungrab(gint keycode, gint modifiers);
+/* gconf.c */
+
+gboolean gconf_applet_set_string (PanelApplet *parent, 
+                                  const char *gconf_key,
+                                  gchar *value,
+                                  gchar *blah);
+
+gchar * gconf_applet_get_string  (PanelApplet *parent, 
+                                  const char *gconf_key,
+                                  gchar *blah);
+
+gboolean gconf_applet_set_int (PanelApplet *parent, 
+                                  const char *gconf_key,
+                                  gint value,
+                                  gchar *blah);
+
+gint gconf_applet_get_int  (PanelApplet *parent, 
+                                  const char *gconf_key,
+                                  gchar *blah);
+
+gboolean gconf_applet_set_bool (PanelApplet *parent, 
+                                  const char *gconf_key,
+                                  gboolean value,
+                                  gchar *blah);
+
+gboolean gconf_applet_get_bool  (PanelApplet *parent, 
+                                  const char *gconf_key,
+                                  gchar *blah);
 
 /* Globals */
 gchar * prefixdir;
