@@ -27,34 +27,34 @@
 #include <gnome.h>
 #include <gconf/gconf.h>
 #include <panel-applet.h>
+#include <panel-applet-gconf.h>
 
 #include "history.h"
 #include "preferences.h"
 #include "message.h"
 
-static char *history_command[LENGTH_HISTORY_LIST];
-static void delete_history_entry(int element_number);
+static void delete_history_entry(MCData *mcdata, int element_number);
 
 
 int
-exists_history_entry(int pos)
+exists_history_entry(MCData *mcdata, int pos)
 {
-    return(history_command[pos] != NULL);
+    return(mcdata->history_command[pos] != NULL);
 }
 
 char *
-get_history_entry(int pos)
+get_history_entry(MCData *mcdata, int pos)
 {
-    return(history_command[pos]);
+    return(mcdata->history_command[pos]);
 }
 
 void
-set_history_entry(int pos, char * entry)
+set_history_entry(MCData *mcdata, int pos, char * entry)
 {
-    if(history_command[pos] != NULL)
-	free(history_command[pos]);
-    history_command[pos] = (char *)malloc(sizeof(char) * (strlen(entry) + 1));
-    strcpy(history_command[pos], entry);
+    if(mcdata->history_command[pos] != NULL)
+	free(mcdata->history_command[pos]);
+    mcdata->history_command[pos] = (char *)malloc(sizeof(char) * (strlen(entry) + 1));
+    strcpy(mcdata->history_command[pos], entry);
 }
 
 /* load_history indicates whether the history list is being loaded at startup.
@@ -72,25 +72,25 @@ append_history_entry(MCData *mcdata, char * entry, gboolean load_history)
     /* remove older dupes */
     for(pos = 0; pos <= LENGTH_HISTORY_LIST - 1; pos++)
 	{
-	    if(exists_history_entry(pos) && strcmp(entry, history_command[pos]) == 0)
+	    if(exists_history_entry(mcdata, pos) && strcmp(entry, mcdata->history_command[pos]) == 0)
 		/* dupe found */
-		delete_history_entry(pos);
+		delete_history_entry(mcdata, pos);
 	}
 
     /* delete oldest entry */
-    if(history_command[0] != NULL)
-	free(history_command[0]);
+    if(mcdata->history_command[0] != NULL)
+	free(mcdata->history_command[0]);
 
     /* move entries */
     for(pos = 0; pos < LENGTH_HISTORY_LIST - 1; pos++)
 	{
-	    history_command[pos] = history_command[pos+1];
-	    /* printf("%s\n", history_command[pos]); */
+	    mcdata->history_command[pos] = mcdata->history_command[pos+1];
+	    /* printf("%s\n", mcdata->history_command[pos]); */
 	}
 
     /* append entry */
-    history_command[LENGTH_HISTORY_LIST - 1] = (char *)malloc(sizeof(char) * (strlen(entry) + 1));
-    strcpy(history_command[LENGTH_HISTORY_LIST - 1], entry);
+    mcdata->history_command[LENGTH_HISTORY_LIST - 1] = (char *)malloc(sizeof(char) * (strlen(entry) + 1));
+    strcpy(mcdata->history_command[LENGTH_HISTORY_LIST - 1], entry);
     
     if (load_history)
     	return;
@@ -103,8 +103,8 @@ append_history_entry(MCData *mcdata, char * entry, gboolean load_history)
 	    GConfValue *entry;
 	    
 	    entry = gconf_value_new (GCONF_VALUE_STRING);
-	    if(exists_history_entry(i)) {
-	    	gconf_value_set_string (entry, (gchar *) get_history_entry(i));
+	    if(exists_history_entry(mcdata, i)) {
+	    	gconf_value_set_string (entry, (gchar *) get_history_entry(mcdata, i));
 	    	list = g_slist_append (list, entry);
 	    }        
 	    
@@ -128,12 +128,12 @@ append_history_entry(MCData *mcdata, char * entry, gboolean load_history)
 }
 
 void
-delete_history_entry(int element_number)
+delete_history_entry(MCData *mcdata, int element_number)
 {
     int pos;
 
     for(pos = element_number; pos > 0; --pos)
-	history_command[pos] = history_command[pos - 1];
+	mcdata->history_command[pos] = mcdata->history_command[pos - 1];
 
-    history_command[0] = NULL;   
+    mcdata->history_command[0] = NULL;   
 }
