@@ -6,14 +6,11 @@
 #include <panel-applet.h>
 #include "mini-commander_applet.h"
 
-#define LENGTH_HISTORY_LIST       50
 #define MAX_COMMAND_LENGTH        500
 #define MAX_NUM_MACROS            99
 #define MAX_NUM_MACRO_PARAMETERS  100
 #define MAX_MACRO_PATTERN_LENGTH  25
 
-
-
 struct struct_properties
 {
     int show_time;
@@ -39,9 +36,6 @@ struct struct_properties
     regex_t *macro_regex[MAX_NUM_MACROS];
 };
 
-
-extern GtkWidget *applet;
-
 properties * load_session(MCData *mcdata);
 
 gint save_session_signal(GtkWidget *widget, const char *privcfgpath, const char *globcfgpath);
