@@ -84,12 +84,6 @@
 #define VOLUME_MAX 255
 #endif
 
-#include "volume-zero.xpm"
-#include "volume-min.xpm"
-#include "volume-medium.xpm"
-#include "volume-max.xpm"
-#include "volume-mute.xpm"
-
 #define IS_PANEL_HORIZONTAL(o) (o == PANEL_APPLET_ORIENT_UP || o == PANEL_APPLET_ORIENT_DOWN)
 
 typedef struct {
@@ -125,7 +119,10 @@ static void mixer_start_gmix_cb (BonoboUIComponent *uic,
 void add_atk_namedesc (GtkWidget *widget, const gchar *name, const gchar *desc);
 
 static gint mixerfd = -1;
-static GdkPixbuf *zero_pixbuf = NULL, *min_pixbuf, *medium_pixbuf, *max_pixbuf, *mute_pixbuf;
+static GdkPixbuf *zero_pixbuf = NULL, *min_pixbuf, 
+		 *medium_pixbuf, *max_pixbuf, *mute_pixbuf;
+static GdkPixbuf *zero_pixbuf_small = NULL, *min_pixbuf_small, 
+		 *medium_pixbuf_small, *max_pixbuf_small, *mute_pixbuf_small;
 static gchar *run_mixer_cmd = NULL;
 
 static const gchar *access_name = N_("Volume Control");     
@@ -343,45 +340,65 @@ mixer_update_slider (MixerData *data)
 static void
 mixer_update_image (MixerData *data)
 {
-	gint       vol;
-	GdkPixbuf *pixbuf;
+	gint vol, size;
+	gboolean small;
+	GdkPixbuf *pixbuf, *copy = NULL, *new_pixbuf;
 
 	vol = data->vol;
+	size = panel_applet_get_size (PANEL_APPLET (data->applet));
+	if (size > GNOME_Vertigo_PANEL_X_SMALL)
+		small = FALSE;
+	else
+		small = TRUE;
 	
 	if (vol <= 0) {
-		pixbuf = zero_pixbuf;
+		pixbuf = small ? zero_pixbuf_small : zero_pixbuf;
 	}
 	else if (vol <= VOLUME_MAX / 3) {
-		pixbuf = min_pixbuf;
+		pixbuf = small ? min_pixbuf_small : min_pixbuf;
 	}
 	else if (vol <= 2 * VOLUME_MAX / 3) {
-		pixbuf = medium_pixbuf;
+		pixbuf = small ? medium_pixbuf_small : medium_pixbuf;
 	}
 	else {
-		pixbuf = max_pixbuf;
+		pixbuf = small ? max_pixbuf_small : max_pixbuf;
 	}
 
-	if (!data->mute) {
-		gtk_image_set_from_pixbuf (GTK_IMAGE (data->image), pixbuf);
-	} else {
-		GdkPixbuf *copy = gdk_pixbuf_copy (pixbuf);
+	if (data->mute) {
+		GdkPixbuf *mute = small ? mute_pixbuf_small : mute_pixbuf;
+		copy = gdk_pixbuf_copy (pixbuf);
 
-		gdk_pixbuf_composite (mute_pixbuf,
+		gdk_pixbuf_composite (mute,
 				      copy,
 				      0,
 				      0,
-				      gdk_pixbuf_get_width (mute_pixbuf),
-				      gdk_pixbuf_get_height (mute_pixbuf),
+				      gdk_pixbuf_get_width (mute),
+				      gdk_pixbuf_get_height (mute),
 				      0,
 				      0,
 				      1.0,
 				      1.0,
 				      GDK_INTERP_BILINEAR,
 				      127);
-
-		gtk_image_set_from_pixbuf (GTK_IMAGE (data->image), copy);
-		g_object_unref (copy);
+		pixbuf = copy;
 	}
+
+	if (size == GNOME_Vertigo_PANEL_X_SMALL || size == GNOME_Vertigo_PANEL_MEDIUM) {
+		/* Don't need to scale for this size */
+		gtk_image_set_from_pixbuf (GTK_IMAGE (data->image), pixbuf);
+		
+	}
+	else {
+		new_pixbuf = gdk_pixbuf_scale_simple (pixbuf,
+					size, size, GDK_INTERP_BILINEAR); 
+		gtk_image_set_from_pixbuf (GTK_IMAGE (data->image), new_pixbuf);
+		g_object_unref (new_pixbuf);
+	}
+	
+	gtk_widget_set_size_request (GTK_WIDGET (data->frame),
+                                     MAX (11, size-1),MAX (11, size-1));
+        if (copy)
+        	g_object_unref (copy);
 }
 
 static gboolean
@@ -691,6 +708,7 @@ applet_change_background_cb (PanelApplet               *applet,
 		GtkRcStyle *rc_style = gtk_rc_style_new ();
 
 		gtk_widget_modify_style (data->applet, rc_style);
+		gtk_rc_style_unref (rc_style);
 	}
 	else if (type == PANEL_COLOR_BACKGROUND) {
 		gtk_widget_modify_bg (data->applet,
@@ -712,22 +730,8 @@ applet_change_orient_cb (GtkWidget *w, PanelAppletOrient o, MixerData *data)
 static void
 applet_change_size_cb (GtkWidget *w, gint size, MixerData *data)
 {
-	gint vol;
-
 	mixer_popup_hide (data, FALSE);
-
-	/* Really only needed to fit on the ultra small panel,
-	 * but we could scale up for the bigger ones...
-	 */
-	if (IS_PANEL_HORIZONTAL (data->orientation)) {
-		gtk_widget_set_size_request (GTK_WIDGET (data->frame),
-					     23,
-					     MIN (23, size));
-	} else {
-		gtk_widget_set_size_request (GTK_WIDGET (data->frame),
-					     MIN (23, size),
-					     23);
-	}
+	mixer_update_image (data);
 }
 
 static void
@@ -788,7 +792,7 @@ mixer_about_cb (BonoboUIComponent *uic,
                 return;
         }
         
-        file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "gnome-mixer-applet.png", TRUE, NULL);
+        file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "mixer/gnome-mixer-applet.png", TRUE, NULL);
         pixbuf = gdk_pixbuf_new_from_file (file, NULL);
         g_free (file);
 
@@ -801,7 +805,7 @@ mixer_about_cb (BonoboUIComponent *uic,
                                  pixbuf);
 
 	gtk_window_set_wmclass (GTK_WINDOW(about), "volume control", "Volume Control");
-	gnome_window_icon_set_from_file (GTK_WINDOW (about), GNOME_ICONDIR"/gnome-mixer-applet.png");
+	gnome_window_icon_set_from_file (GTK_WINDOW (about), GNOME_ICONDIR"/mixer/gnome-mixer-applet.png");
         g_signal_connect (G_OBJECT (about), "destroy",
                           G_CALLBACK (gtk_widget_destroyed),
 	                  &about);
@@ -887,6 +891,34 @@ mixer_ui_component_event (BonoboUIComponent            *comp,
 	}
 }
 
+static void
+initialize_pixbufs ()
+{
+	zero_pixbuf = gdk_pixbuf_new_from_file (GNOME_ICONDIR"/mixer/volume-zero.png",
+						NULL);
+	min_pixbuf = gdk_pixbuf_new_from_file (GNOME_ICONDIR"/mixer/volume-min.png",
+						   NULL);
+	medium_pixbuf = gdk_pixbuf_new_from_file (GNOME_ICONDIR"/mixer/volume-medium.png",
+						      NULL);
+	max_pixbuf = gdk_pixbuf_new_from_file (GNOME_ICONDIR"/mixer/volume-max.png",
+						   NULL);
+	mute_pixbuf = gdk_pixbuf_new_from_file (GNOME_ICONDIR"/mixer/volume-mute.png",
+						    NULL);
+						    
+	zero_pixbuf_small = gdk_pixbuf_new_from_file (GNOME_ICONDIR"/mixer/volume-zero-small.png",
+						NULL);
+	min_pixbuf_small = gdk_pixbuf_new_from_file (GNOME_ICONDIR"/mixer/volume-min-small.png",
+						   NULL);
+	medium_pixbuf_small = gdk_pixbuf_new_from_file (GNOME_ICONDIR"/mixer/volume-medium-small.png",
+						      NULL);
+	max_pixbuf_small = gdk_pixbuf_new_from_file (GNOME_ICONDIR"/mixer/volume-max-small.png",
+						   NULL);
+	mute_pixbuf_small = gdk_pixbuf_new_from_file (GNOME_ICONDIR"/mixer/volume-mute-small.png",
+						    NULL);
+
+
+}
+
 const BonoboUIVerb mixer_applet_menu_verbs [] = {
 	BONOBO_UI_UNSAFE_VERB ("RunMixer", mixer_start_gmix_cb),
 	BONOBO_UI_UNSAFE_VERB ("Mute",     mixer_mute_cb),
@@ -940,11 +972,7 @@ mixer_applet_create (PanelApplet *applet)
 	data = g_new0 (MixerData, 1);
 
 	if (zero_pixbuf == NULL) {
-		zero_pixbuf = gdk_pixbuf_new_from_xpm_data (volume_zero_xpm);
-		min_pixbuf = gdk_pixbuf_new_from_xpm_data (volume_min_xpm);
-		medium_pixbuf = gdk_pixbuf_new_from_xpm_data (volume_medium_xpm);
-		max_pixbuf = gdk_pixbuf_new_from_xpm_data (volume_max_xpm);
-		mute_pixbuf = gdk_pixbuf_new_from_xpm_data (volume_mute_xpm);
+		initialize_pixbufs ();
 	}
 	
 	/* Try to find some mixers - sdtaudiocontrol is on Solaris and is needed
